# Generated by Django 3.2.18 on 2023-05-12 14:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('payer', '0002_add_missing_fields'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='payer',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='payertype',
            options={'managed': True},
        ),
    ]
